import { BottomOverlayRow, TextLabelFactory, ComponentFactory } from "../";
/** Represents a notification that is displayed in the corner of the screen */
export declare class Notification extends BottomOverlayRow {
    timeout: number;
    /** Close all notifications currently displayed on screen */
    static closeAll(): void;
    /** Global alignment setting (do not change after display) */
    static SCREEN_CORNER: Notification.ScreenCorner;
    /** Global margin setting in px (do not change after display) */
    static HORZ_OUTER_MARGIN_PX: number;
    /** Global margin setting in px (do not change after display) */
    static VERT_OUTER_MARGIN_PX: number;
    /** Global margin setting in px (do not change after display) */
    static VERT_INNER_MARGIN_PX: number;
    /** Global max width setting (CSS length, defaults to 22rem) */
    static MAX_WIDTH: string;
    /** Global default background color (CSS color) */
    static BG_COLOR: string;
    /** Global default foreground color (CSS color) */
    static FG_COLOR: string;
    /** Create a notification with given content, and optional timeout in ms (default 4000) */
    constructor(content: string | TextLabelFactory | ComponentFactory.SpecElt[], timeout?: number);
    /** Display this notification on screen */
    display(): this | undefined;
    /** Remove this notification from the screen */
    close(): void;
}
/** Represents a Bootstrap "info" alert styled notification */
export declare class InfoAlertNotification extends Notification {
    /** Display this notification on screen */
    display(): this | undefined;
}
/** Represents a Bootstrap "success" alert styled notification */
export declare class SuccessAlertNotification extends Notification {
    /** Display this notification on screen */
    display(): this | undefined;
}
/** Represents a Bootstrap "warning" alert styled notification */
export declare class WarningAlertNotification extends Notification {
    /** Display this notification on screen */
    display(): this | undefined;
}
/** Represents a Bootstrap "danger" alert styled notification */
export declare class DangerAlertNotification extends Notification {
    /** Display this notification on screen */
    display(): this | undefined;
}
export declare namespace Notification {
    /** Notification display alignment options */
    enum ScreenCorner {
        /** Bottom left corner */
        BottomLeft = 0,
        /** Bottom right corner */
        BottomRight = 1,
        /** Bottom (center) */
        BottomCenter = 2,
        /** Top left corner */
        TopLeft = 3,
        /** Top right corner */
        TopRight = 4,
        /** Top (center) */
        TopCenter = 5,
    }
}
export default Notification;
